==> apache-datafusion-comet-0.12.0.tar.gz: apache-datafusion-comet-0.12.0/spark/src/main/scala/org/apache/comet/serde/decimalExpressions.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.comet.serde

import org.apache.spark.sql.catalyst.expressions.{Attribute, MakeDecimal, UnscaledValue}
import org.apache.spark.sql.types.{DecimalType, LongType}

import org.apache.comet.serde.QueryPlanSerde.{exprToProtoInternal, optExprWithInfo, scalarFunctionExprToProtoWithReturnType}

object CometUnscaledValue extends CometExpressionSerde[UnscaledValue] {
  override def convert(
      expr: UnscaledValue,
      inputs: Seq[Attribute],
      binding: Boolean): Option[ExprOuterClass.Expr] = {
    val childExpr = exprToProtoInternal(expr.child, inputs, binding)
    val optExpr =
      scalarFunctionExprToProtoWithReturnType("unscaled_value", LongType, false, childExpr)
    optExprWithInfo(optExpr, expr, expr.child)

  }
}

object CometMakeDecimal extends CometExpressionSerde[MakeDecimal] {
  override def convert(
      expr: MakeDecimal,
      inputs: Seq[Attribute],
      binding: Boolean): Option[ExprOuterClass.Expr] = {
    val childExpr = exprToProtoInternal(expr.child, inputs, binding)
    val optExpr = scalarFunctionExprToProtoWithReturnType(
      "make_decimal",
      DecimalType(expr.precision, expr.scale),
      failOnError = !expr.nullOnOverflow,
      childExpr)
    optExprWithInfo(optExpr, expr, expr.child)

  }
}

==> apache-datafusion-comet-0.13.0.tar.gz: apache-datafusion-comet-0.13.0/spark/src/main/scala/org/apache/comet/serde/decimalExpressions.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.comet.serde

import org.apache.spark.sql.catalyst.expressions.{Attribute, MakeDecimal, UnscaledValue}
import org.apache.spark.sql.types.{DecimalType, LongType}

import org.apache.comet.serde.QueryPlanSerde.{exprToProtoInternal, optExprWithInfo, scalarFunctionExprToProtoWithReturnType}

object CometUnscaledValue extends CometExpressionSerde[UnscaledValue] {
  override def convert(
      expr: UnscaledValue,
      inputs: Seq[Attribute],
      binding: Boolean): Option[ExprOuterClass.Expr] = {
    val childExpr = exprToProtoInternal(expr.child, inputs, binding)
    val optExpr =
      scalarFunctionExprToProtoWithReturnType("unscaled_value", LongType, false, childExpr)
    optExprWithInfo(optExpr, expr, expr.child)

  }
}

object CometMakeDecimal extends CometExpressionSerde[MakeDecimal] {

  override def getSupportLevel(expr: MakeDecimal): SupportLevel = {
    expr.child.dataType match {
      case LongType => Compatible()
      case other => Unsupported(Some(s"Unsupported input data type: $other"))
    }
  }

  override def convert(
      expr: MakeDecimal,
      inputs: Seq[Attribute],
      binding: Boolean): Option[ExprOuterClass.Expr] = {
    val childExpr = exprToProtoInternal(expr.child, inputs, binding)
    val optExpr = scalarFunctionExprToProtoWithReturnType(
      "make_decimal",
      DecimalType(expr.precision, expr.scale),
      failOnError = !expr.nullOnOverflow,
      childExpr)
    optExprWithInfo(optExpr, expr, expr.child)

  }
}
